<?php
/**
 * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
 *
 * @license EUPL, Version 1.2 or later (the "License")
 *
 * Licensed under the EUPL, Version 1.2 or later (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

namespace OCA\Liiibre\AppInfo;

use OCA\Liiibre\BeforeTemplateRenderedListener;
use OCA\Liiibre\Capabilities;
use OCA\Liiibre\SitesManager;
use OCA\Files\Event\LoadAdditionalScriptsEvent;
use OCP\AppFramework\App;
use OCP\AppFramework\Bootstrap\IBootContext;
use OCP\AppFramework\Bootstrap\IBootstrap;
use OCP\AppFramework\Bootstrap\IRegistrationContext;
use OCP\AppFramework\Http\Events\BeforeTemplateRenderedEvent;
use OCP\INavigationManager;
use OCP\Util;

class Application extends App implements IBootstrap {

	public const APP_ID = 'liiibre';

	public function __construct() {
		parent::__construct(self::APP_ID);
	}


	public function register(IRegistrationContext $context): void {
		$context->registerCapability(Capabilities::class);
		$context->registerEventListener(BeforeTemplateRenderedEvent::class, BeforeTemplateRenderedListener::class);
		$context->registerEventListener(LoadAdditionalScriptsEvent::class, BeforeTemplateRenderedListener::class);
	}

	public function boot(IBootContext $context): void {
		$context->injectFn([$this, 'registerSites']);
		Util::addStyle(self::APP_ID, 'style');
	}

	public function registerSites(
		SitesManager $sitesManager,
		INavigationManager $navigationManager): void {
 		$entries = $sitesManager->getNavigationEntries();

 		foreach ($entries as $id => $entry) {
 			$navigationManager->add($entry);
 		}
	}
}