<?php
/**
 * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
 *
 * @license EUPL, Version 1.2 or later (the "License")
 *
 * Licensed under the EUPL, Version 1.2 or later (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

namespace OCA\Liiibre\Controller;

use OCA\Liiibre\Exceptions\SiteNotFoundException;
use OCA\Liiibre\SitesManager;
use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\ContentSecurityPolicy;
use OCP\AppFramework\Http\RedirectResponse;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\IConfig;
use OCP\INavigationManager;
use OCP\IRequest;
use OCP\IURLGenerator;

class SiteController extends Controller {
	protected IConfig $config;
	protected SitesManager $sitesManager;
	protected INavigationManager $navigationManager;
	protected IURLGenerator $url;

	public function __construct(string $appName,
		IRequest $request,
		IConfig $config,
		INavigationManager $navigationManager,
		SitesManager $sitesManager,
		IURLGenerator $url) {
		parent::__construct($appName, $request);
		$this->config = $config;
		$this->sitesManager = $sitesManager;
		$this->navigationManager = $navigationManager;
		$this->url = $url;
	}

	/**
	 * @NoAdminRequired
	 * @NoCSRFRequired
	 *
	 * @return TemplateResponse|RedirectResponse
	 */
	public function showPage(int $id) {
		try {
			$site = $this->sitesManager->getSiteById($id);
			return $this->createResponse($id, $site);
		} catch (SiteNotFoundException $e) {
			return new RedirectResponse($this->url->linkToDefaultPageUrl());
		}
	}

	protected function createResponse(int $id, array $site): TemplateResponse {
		$this->navigationManager->setActiveEntry('liiibre_index' . $id);

		$response = new TemplateResponse('liiibre', 'frame', [
			'url' => $site['url'],
			'name' => $site['name'],
		], 'user');

		$policy = new ContentSecurityPolicy();
		$policy->addAllowedWorkerSrcDomain('*');
		$policy->addAllowedFrameDomain('*');
		$response->setContentSecurityPolicy($policy);

		return $response;
	}
}
