<?php
/**
 * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
 *
 * @author Joas Schilling <coding@schilljs.com>
 *
 * @license EUPL, Version 1.2 or later (the "License")
 *
 * Licensed under the EUPL, Version 1.2 or later (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

namespace OCA\Liiibre\Migration;


use OCP\App\IAppManager;
use OCP\Files\IAppData;
use OCP\Files\NotFoundException;
use OCP\Files\SimpleFS\ISimpleFolder;
use OCP\Migration\IOutput;
use OCP\Migration\IRepairStep;

class CopyDefaultIcons implements IRepairStep {
	protected IAppManager $appManager;
	protected IAppData $appData;

	public function __construct(IAppManager $appManager, IAppData $appData) {
		$this->appManager = $appManager;
		$this->appData = $appData;
	}

	public function getName(): string {
		return 'Copy default images to the app data directory';
	}

	public function run(IOutput $output): void {
		try {
			$folder = $this->appData->getFolder('icons');
		} catch (NotFoundException $e) {
			$folder = $this->appData->newFolder('icons');
		}

		$this->copyDefaultIcon($output, $folder, 'external.svg');
		$this->copyDefaultIcon($output, $folder, 'external-dark.svg');
		$this->copyDefaultIcon($output, $folder, 'settings.svg');
		$this->copyDefaultIcon($output, $folder, 'compte.png');
		$this->copyDefaultIcon($output, $folder, 'chat.png');
		$this->copyDefaultIcon($output, $folder, 'conversation.png');
		$this->copyDefaultIcon($output, $folder, 'users.png');
		$this->copyDefaultIcon($output, $folder, 'lifesaver.png');
		$this->copyDefaultIcon($output, $folder, 'meet.png');
		$this->copyDefaultIcon($output, $folder, 'meet-dark.png');
		$this->copyDefaultIcon($output, $folder, 'quota.png');
	}

	protected function copyDefaultIcon(IOutput $output, ISimpleFolder $folder, string $file): void {
		try {
			$folder->getFile($file);
			$output->info(sprintf('Icon %s already exists', $file));
			return;
		} catch (NotFoundException $exception) {
		}

		// Default icon is missing, copy it from img/
		$content = file_get_contents($this->appManager->getAppPath('liiibre') . '/img/' . $file);
		if ($content === false) {
			$output->info(sprintf('Could not read icon %s', $file));
			return;
		}

		$LiiibreSVG = $folder->newFile($file);
		$LiiibreSVG->putContent($content);

		$output->info(sprintf('Icon %s copied successfully', $file));
	}
}
