<?php
/**
 * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
 *
 * @license EUPL, Version 1.2 or later (the "License")
 *
 * Licensed under the EUPL, Version 1.2 or later (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

namespace OCA\Liiibre\Settings;

use OCP\IURLGenerator;
use OCP\Settings\IIconSection;

class Section implements IIconSection {
	private IURLGenerator $url;

	public function __construct(IURLGenerator $url) {
		$this->url = $url;
	}

	/**
	 * returns the relative path to an 16*16 icon describing the section.
	 * e.g. '/core/img/places/files.svg'
	 *
	 * @since 12
	 */
	public function getIcon(): string {
		return $this->url->imagePath('external', 'external-dark.svg');
	}

	/**
	 * returns the ID of the section. It is supposed to be a lower case string,
	 * e.g. 'ldap'
	 *
	 * @since 9.1
	 */
	public function getID(): string {
		return 'liiibre';
	}

	/**
	 * returns the translated name as it should be displayed, e.g. 'LDAP / AD
	 * integration'. Use the L10N service to translate it.
	 * @since 9.1
	 */
	public function getName(): string {
		return 'Liiibre';
	}

	/**
	 * return whether the form should be rather on the top or bottom of
	 * the settings navigation. The sections are arranged in ascending order of
	 * the priority values. It is required to return a value between 0 and 99.
	 * @since 9.1
	 * 
	 * E.g.: 70
	 */
	public function getPriority(): int {
		return 55;
	}
}
